@@ -9,7 +9,6 @@ import shutil
 import sys
 
 import gentoolkit.pprinter as pp
-import portage
 from portage.emaint.main import TaskHandler
 from portage.emaint.modules.binhost import binhost
 
@@ -36,7 +35,6 @@ class CleanUp:
         @rtype: int
         @return: total size that was cleaned
         """
-        file_type = "file"
         clean_size = 0
         # clean all entries one by one; sorting helps reading
         for key in sorted(clean_dict):
@@ -57,7 +55,6 @@ class CleanUp:
         @rtype: int
         @return: total size that was cleaned
         """
-        file_type = "binary package"
         clean_size = 0
         # clean all entries one by one; sorting helps reading
         for location, loc_clean_dict in clean_dict.items():
@@ -100,8 +97,10 @@ class CleanUp:
             for location, loc_clean_dict in clean_dict.items():
                 print(" * Location", pp.path(location))
                 for key in sorted(loc_clean_dict):
-                    (binpkg, debugpack) = loc_clean_dict[key]
-                    key_size = self._get_size([binpkg, debugpack] if debugpack else [binpkg])
+                    binpkg, debugpack = loc_clean_dict[key]
+                    key_size = self._get_size(
+                        [binpkg, debugpack] if debugpack else [binpkg]
+                    )
                     self.controller(key_size, key, loc_clean_dict[key], file_type)
                     clean_size += key_size
 
@@ -158,7 +157,7 @@ class CleanUp:
         rm_files = []
         rm_size = 0
 
-        if (sz := self._get_size_valid_symlink(files[0])):
+        if sz := self._get_size_valid_symlink(files[0]):
             rm_files.append(files[0])
             rm_size += sz
 
