@@ -594,6 +594,13 @@ def doAction(action, options, exclude={}, output=None):
 
     # actually clean files if something was found
     if clean_me or vcs:
+        file_count = len(clean_me)
+        if action in ["packages"]:
+            file_count = sum(
+                2 if entry[1] else 1
+                for loc_entries in clean_me.values()
+                for entry in loc_entries.values()
+            )
         # verbose pretend message
         if options["pretend"] and not options["quiet"]:
             output.einfo("Here are the " + files_type + " that would be deleted:")
@@ -604,7 +611,8 @@ def doAction(action, options, exclude={}, output=None):
         if options["pretend"]:
             if options["skip-vcs"] or not options["destructive"]:
                 vcs = {}
-            clean_size = cleaner.pretend_clean(clean_me, vcs)
+            file_type = "binary package" if action in ["packages"] else "file"
+            clean_size = cleaner.pretend_clean(clean_me, vcs, file_type)
         elif action in ["distfiles"]:
             if options["skip-vcs"] or not options["destructive"]:
                 vcs = {}
@@ -612,13 +620,10 @@ def doAction(action, options, exclude={}, output=None):
         elif action in ["packages"]:
             clean_size = cleaner.clean_pkgs(clean_me, pkgdir)
         # vocabulary for final message
-        if options["pretend"]:
-            verb = "would be"
-        else:
-            verb = "were"
+        verb = "would be" if options["pretend"] else "were"
         # display freed space
         if not options["quiet"]:
-            output.total("normal", clean_size, len(clean_me) + len(vcs), verb, action)
+            output.total("normal", clean_size, file_count + len(vcs), verb, action)
     # nothing was found
     elif not options["quiet"]:
         output.einfo("Your " + action + " directory was already clean.")
@@ -662,7 +667,8 @@ def doAction(action, options, exclude={}, output=None):
                 output.set_colors("invalid")
                 output.list_pkgs(invalids)
                 clean_size = cleaner.clean_pkgs(invalids, pkgdir)
-                output.total("invalid", clean_size, len(invalids), verb, action)
+                invalid_count = sum(len(pkgs) for pkgs in invalids.values())
+                output.total("invalid", clean_size, invalid_count, verb, action)
             else:
                 cleaner.clean_pkgs(invalids, pkgdir)
 
