@@ -136,7 +136,11 @@ class OutputControl:
         if not self.options["quiet"]:
             # pretty print mode
             if file_type == "binary package" and clean_list[1] is not None:
-                print(self.prettySize(size, True), self.pkg_color(key), "(+ debug tarball)")
+                print(
+                    self.prettySize(size, True),
+                    self.pkg_color(key),
+                    "(+ debug tarball)",
+                )
             else:
                 print(self.prettySize(size, True), self.pkg_color(key))
         elif self.options["pretend"] or self.options["interactive"]:
@@ -203,7 +207,7 @@ class OutputControl:
     def list_pkgs(self, loc_pkgs):
         """outputs the packages to stdout
 
-        @param pkgs: dict. of {location: {cat/pkg-ver: src_uri,} }
+        @param loc_pkgs: dict. of {location: {cat/pkg-ver: src_uri,} }
         """
         indent = " " * 12
         for pkgs in loc_pkgs.values():
