@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# Copyright 2003-2024 Gentoo Authors
+# Copyright 2003-2026 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
 
@@ -132,7 +132,9 @@ class DistfilesSearch:
         if (not destructive) or fetch_restricted:
             self.output("...non-destructive type search")
             pkgs, _deprecated = self._non_destructive(destructive, fetch_restricted)
-            deprecated.update(_deprecated)
+            if _deprecated:
+                # use the same structure as invalid binpkgs for list_pkgs()
+                deprecated.update({_distdir: _deprecated})
             installed_included = True
         if destructive:
             self.output(
@@ -141,7 +143,9 @@ class DistfilesSearch:
             pkgs, _deprecated = self._destructive(
                 package_names, exclude, pkgs, installed_included
             )
-            deprecated.update(_deprecated)
+            if _deprecated:
+                # use the same structure as invalid binpkgs for list_pkgs()
+                deprecated.update({_distdir: _deprecated})
         # gather the files to be cleaned
         self.output("...checking limits for %d ebuild sources" % len(pkgs))
 
@@ -388,16 +392,14 @@ class DistfilesSearch:
         for cpv in cpvs:
             # get SRC_URI and RESTRICT from aux_get
             try:  # main portdb
-                (src_uri, restrict) = self.portdb.aux_get(cpv, ["SRC_URI", "RESTRICT"])
+                src_uri, restrict = self.portdb.aux_get(cpv, ["SRC_URI", "RESTRICT"])
                 # keep fetch-restricted check
                 # inside try so it is bypassed on KeyError
                 if "fetch" in restrict:
                     pkgs[cpv] = src_uri
             except KeyError:
                 try:  # installed vardb
-                    (src_uri, restrict) = self.vardb.aux_get(
-                        cpv, ["SRC_URI", "RESTRICT"]
-                    )
+                    src_uri, restrict = self.vardb.aux_get(cpv, ["SRC_URI", "RESTRICT"])
                     deprecated[cpv] = src_uri
                     self.output(DEPRECATED % cpv)
                     # keep fetch-restricted check
@@ -676,7 +678,7 @@ def findPackages(
 
     # Load binrepos.conf if possible, get all cache locations
     binrepos_conf_path = os.path.join(
-        settings['PORTAGE_CONFIGROOT'], portage.const.BINREPOS_CONF_FILE
+        settings["PORTAGE_CONFIGROOT"], portage.const.BINREPOS_CONF_FILE
     )
     binrepos_conf = BinRepoConfigLoader((binrepos_conf_path,), settings)
     locations = {pkgdir}
@@ -724,7 +726,10 @@ def findPackages(
                     binpkg_key = mk_binpkg_key(drop_cpv)
                     binpkg_path = bin_dbapi.bintree.getname(drop_cpv)
                     debuginfo_path = _find_debuginfo_tarball(drop_cpv, cp)
-                    dead_binpkgs.setdefault(location, {})[binpkg_key] = (binpkg_path, debuginfo_path)
+                    dead_binpkgs.setdefault(location, {})[binpkg_key] = (
+                        binpkg_path,
+                        debuginfo_path,
+                    )
 
                     if new_time < old_time:
                         continue
@@ -769,16 +774,20 @@ def findPackages(
 
             binpkg_path = bin_dbapi.bintree.getname(cpv)
             debuginfo_path = _find_debuginfo_tarball(cpv, cp)
-            dead_binpkgs.setdefault(location, {})[binpkg_key] = (binpkg_path, debuginfo_path)
+            dead_binpkgs.setdefault(location, {})[binpkg_key] = (
+                binpkg_path,
+                debuginfo_path,
+            )
 
         try:
-            invalid_paths[location] = bin_dbapi.bintree.invalid_paths
-            # A little dirty, but it makes the structure of
-            # invalid_paths match the structure of dead_binpkgs.
-            for file_ in invalid_paths[location]:
-                if len(invalid_paths[location][file_]) == 1:
-                    full_path = invalid_paths[location][file_][0]
-                    invalid_paths[location][file_] = (full_path, None)
+            if len(bin_dbapi.bintree.invalid_paths) > 0:
+                invalid_paths[location] = bin_dbapi.bintree.invalid_paths
+                # A little dirty, but it makes the structure of
+                # invalid_paths match the structure of dead_binpkgs.
+                for file_ in invalid_paths[location]:
+                    if len(invalid_paths[location][file_]) == 1:
+                        full_path = invalid_paths[location][file_][0]
+                        invalid_paths[location][file_] = (full_path, None)
         except AttributeError:
             # if bintree.invalid_paths was not initialized, this is a
             # hard error and we can just return here
